@@ -119,9 +119,9 @@ def say_message() -> None:
     sailing_ship = emojize(":sailboat:")
 
     message = (
-        f"{anatomical_heart} Lia is an open-source CI/CD tool "
+        f"{anatomical_heart} Lia is an open-source CI/CD tool\n"
         f"that eliminates the Fel {mechanical_arm}\n"
-        f" Copyright © 2023 Soul Twin Studios {call_me_hand}, "
+        f" Copyright © 2023 Soul Twin Studios {call_me_hand},\n"
         f"a subsidiary of SailBlack Inc. {sailing_ship}"
     )
     echo(message=message)
@@ -141,7 +141,7 @@ def say_end_message() -> None:
         f"{anatomical_heart} Lia is an open-source CI/CD tool\n"
         f"that eliminates the Fel {mechanical_arm}\n"
         f"Copyright © 2023 Soul Twin Studios {call_me_hand},\n"
-        f"a subsidiary of SailBlack Inc. {sailing_ship}"
+        f"a subsidiary of SailBlack Inc. {sailing_ship}\n"
         f"For more nice things follow us on www.codeberg.org/sail.black"
     )
     echo(message=message)
